#include <iostream>
#include <vector>
#include <algorithm>

#define endl '\n'

using namespace std;

const int MAXN = 5e5 + 3;

vector<int> graph[MAXN];
int edgeIndex[MAXN];

int friends[MAXN];

bool visited[MAXN];
int visitedCounter;

vector<int> firstIteration;
vector<int> positionsInFirstIteration[MAXN];

vector<int> eulerTour;
vector<int> positionsInTour[MAXN];

int slow_solution(int m) {
    int currentFriend = 0;
    int currentCity = 0;
    int days = 0;

    while (currentFriend < m) {
        ++days;

        if (currentCity == friends[currentFriend]) {
            ++currentFriend;
        }

        int nextCity = graph[currentCity][edgeIndex[currentCity]];

        ++edgeIndex[currentCity];
        if (edgeIndex[currentCity] == (int) graph[currentCity].size()) {
            edgeIndex[currentCity] = 0;
        }

        currentCity = nextCity;
    }

    return days;
}

void dfs1(int n) {
    visitedCounter = 0;

    for (int i = 0; i < n; ++i) {
        visited[i] = false;
    }

    int currv = 0;

    while(!(currv == 0 and visitedCounter == n)) {
        firstIteration.push_back(currv);
        positionsInFirstIteration[currv].push_back((int) firstIteration.size());

        if (!visited[currv]) {
            ++visitedCounter;
        }

        visited[currv] = true;

        int nextv = graph[currv][edgeIndex[currv]];

        ++edgeIndex[currv];
        if (edgeIndex[currv] == (int) graph[currv].size()) {
            edgeIndex[currv] = 0;
        }

        currv = nextv;
    }
}

void find_euler_tour(int currv, int parent) {
    eulerTour.push_back(currv);
    positionsInTour[currv].push_back((int) eulerTour.size());

    for (int nextv : graph[currv]) {
        if (nextv == parent) {
            continue;
        }

        find_euler_tour(nextv, currv);

        eulerTour.push_back(currv);
        positionsInTour[currv].push_back((int) eulerTour.size());        
    }
}

void dfs2(int n) {
    visitedCounter = 0;

    for (int i = 0; i < n; ++i) {
        visited[i] = false;
    }

    find_euler_tour(0, -1);

    eulerTour.pop_back();
    positionsInTour[0].pop_back();
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n, m;
    cin >> n >> m;

    for (int from = 0; from < n; ++from) {
        int k;
        cin >> k;

        graph[from].resize(k);

        for (int i = 0; i < k; ++i) {
            int to;
            cin >> to;

            graph[from][i] = to - 1;
        }
    }

    for (int i = 0; i < m; ++i) {
        cin >> friends[i];
        --friends[i];
    }

    dfs1(n);
    dfs2(n);
    
    int firstIterationSize = (int) firstIteration.size();
    int tourSize = (int) eulerTour.size();

    int lastPosInFirstIteration = 0;

    int friendIndex = 0;
    int lastDayBeforeTour = 0;

    while (friendIndex < m) {
        int currentCity = friends[friendIndex];

        int target = upper_bound(positionsInFirstIteration[currentCity].begin(), positionsInFirstIteration[currentCity].end(), lastPosInFirstIteration) - positionsInFirstIteration[currentCity].begin();

         if (target == (int) positionsInFirstIteration[currentCity].size()) {
            lastDayBeforeTour = firstIterationSize;
            break;
         }

         lastDayBeforeTour = positionsInFirstIteration[currentCity][target];
         lastPosInFirstIteration = positionsInFirstIteration[currentCity][target];

         ++friendIndex;
    }

    int lastPosInTour = 0;

    int fullTours = 0;
    int lastDayAfterTour = 0;

    while (friendIndex < m) {
        int currentCity = friends[friendIndex];

        int target = upper_bound(positionsInTour[currentCity].begin(), positionsInTour[currentCity].end(), lastPosInTour) - positionsInTour[currentCity].begin();

        if (target == (int) positionsInTour[currentCity].size()) {
            ++fullTours;
            lastPosInTour = 0;

            target = upper_bound(positionsInTour[currentCity].begin(), positionsInTour[currentCity].end(), lastPosInTour) - positionsInTour[currentCity].begin();
        }

        lastDayAfterTour = fullTours * tourSize + positionsInTour[currentCity][target];
        lastPosInTour = positionsInTour[currentCity][target];

        ++friendIndex;
    }

    cout << lastDayBeforeTour + lastDayAfterTour << endl;   

    return 0;
}